@@ -3,8 +3,8 @@ from datetime import datetime, date, time
 from uuid import UUID
 from sqlmodel import select, text
 from sqlalchemy.orm import selectinload,joinedload
-from healthdatalayer.models import MedicalVisit
-from healthdatalayer.dtos import MedicalCertificateDTO
+from healthdatalayer.models import MedicalVisit,MedicalDiagnosisVisit
+from healthdatalayer.dtos import MedicalCertificateDTO,  DiagnosisDTO, MedicalDiagnosesDTO
 from healthdatalayer.config.db import engines, get_session
 
 class MedicalVisitRepository:
@@ -28,7 +28,7 @@ class MedicalVisitRepository:
                     joinedload(MedicalVisit.client),
                     joinedload(MedicalVisit.collaborator),
                     joinedload(MedicalVisit.speciality),
-                    selectinload(MedicalVisit.medical_diagnosis_visits),
+                    selectinload(MedicalVisit.medical_diagnosis_visits).selectinload(MedicalDiagnosisVisit.medical_diagnosis),
                     selectinload(MedicalVisit.medical_recipe_visits),
                     selectinload(MedicalVisit.organ_system_reviews),
                     selectinload(MedicalVisit.physical_exams)
@@ -73,7 +73,7 @@ class MedicalVisitRepository:
                     joinedload(MedicalVisit.client),
                     joinedload(MedicalVisit.collaborator),
                     joinedload(MedicalVisit.speciality),
-                    selectinload(MedicalVisit.medical_diagnosis_visits),
+                    selectinload(MedicalVisit.medical_diagnosis_visits).selectinload(MedicalDiagnosisVisit.medical_diagnosis),
                     selectinload(MedicalVisit.medical_recipe_visits),
                     selectinload(MedicalVisit.organ_system_reviews),
                     selectinload(MedicalVisit.physical_exams)
@@ -93,7 +93,7 @@ class MedicalVisitRepository:
                     joinedload(MedicalVisit.client),
                     joinedload(MedicalVisit.collaborator),
                     joinedload(MedicalVisit.speciality),
-                    selectinload(MedicalVisit.medical_diagnosis_visits),
+                    selectinload(MedicalVisit.medical_diagnosis_visits).selectinload(MedicalDiagnosisVisit.medical_diagnosis),
                     selectinload(MedicalVisit.medical_recipe_visits),
                     selectinload(MedicalVisit.organ_system_reviews),
                     selectinload(MedicalVisit.physical_exams)
@@ -137,7 +137,7 @@ class MedicalVisitRepository:
                     joinedload(MedicalVisit.client),
                     joinedload(MedicalVisit.collaborator),
                     joinedload(MedicalVisit.speciality),
-                    selectinload(MedicalVisit.medical_diagnosis_visits),
+                    selectinload(MedicalVisit.medical_diagnosis_visits).selectinload(MedicalDiagnosisVisit.medical_diagnosis),
                     selectinload(MedicalVisit.medical_recipe_visits),
                     selectinload(MedicalVisit.organ_system_reviews),
                     selectinload(MedicalVisit.physical_exams)
@@ -173,7 +173,7 @@ class MedicalVisitRepository:
                     joinedload(MedicalVisit.client),
                     joinedload(MedicalVisit.collaborator),
                     joinedload(MedicalVisit.speciality),
-                    selectinload(MedicalVisit.medical_diagnosis_visits),
+                    selectinload(MedicalVisit.medical_diagnosis_visits).selectinload(MedicalDiagnosisVisit.medical_diagnosis),
                     selectinload(MedicalVisit.medical_recipe_visits),
                     selectinload(MedicalVisit.organ_system_reviews),
                     selectinload(MedicalVisit.physical_exams)
@@ -198,7 +198,7 @@ class MedicalVisitRepository:
                     joinedload(MedicalVisit.client),
                     joinedload(MedicalVisit.collaborator),
                     joinedload(MedicalVisit.speciality),
-                    selectinload(MedicalVisit.medical_diagnosis_visits),
+                    selectinload(MedicalVisit.medical_diagnosis_visits).selectinload(MedicalDiagnosisVisit.medical_diagnosis),
                     selectinload(MedicalVisit.medical_recipe_visits),
                     selectinload(MedicalVisit.organ_system_reviews),
                     selectinload(MedicalVisit.physical_exams)
@@ -235,7 +235,7 @@ class MedicalVisitRepository:
                     joinedload(MedicalVisit.client),
                     joinedload(MedicalVisit.collaborator),
                     joinedload(MedicalVisit.speciality),
-                    selectinload(MedicalVisit.medical_diagnosis_visits),
+                    selectinload(MedicalVisit.medical_diagnosis_visits).selectinload(MedicalDiagnosisVisit.medical_diagnosis),
                     selectinload(MedicalVisit.medical_recipe_visits),
                     selectinload(MedicalVisit.organ_system_reviews),
                     selectinload(MedicalVisit.physical_exams)
@@ -259,7 +259,7 @@ class MedicalVisitRepository:
                     joinedload(MedicalVisit.client),
                     joinedload(MedicalVisit.collaborator),
                     joinedload(MedicalVisit.speciality),
-                    selectinload(MedicalVisit.medical_diagnosis_visits),
+                    selectinload(MedicalVisit.medical_diagnosis_visits).selectinload(MedicalDiagnosisVisit.medical_diagnosis),
                     selectinload(MedicalVisit.medical_recipe_visits),
                     selectinload(MedicalVisit.organ_system_reviews),
                     selectinload(MedicalVisit.physical_exams)
@@ -280,7 +280,7 @@ class MedicalVisitRepository:
                     joinedload(MedicalVisit.client),
                     joinedload(MedicalVisit.collaborator),
                     joinedload(MedicalVisit.speciality),
-                    selectinload(MedicalVisit.medical_diagnosis_visits),
+                    selectinload(MedicalVisit.medical_diagnosis_visits).selectinload(MedicalDiagnosisVisit.medical_diagnosis),
                     selectinload(MedicalVisit.medical_recipe_visits),
                     selectinload(MedicalVisit.organ_system_reviews),
                     selectinload(MedicalVisit.physical_exams)
@@ -301,7 +301,7 @@ class MedicalVisitRepository:
                     joinedload(MedicalVisit.client),
                     joinedload(MedicalVisit.collaborator),
                     joinedload(MedicalVisit.speciality),
-                    selectinload(MedicalVisit.medical_diagnosis_visits),
+                    selectinload(MedicalVisit.medical_diagnosis_visits).selectinload(MedicalDiagnosisVisit.medical_diagnosis),
                     selectinload(MedicalVisit.medical_recipe_visits),
                     selectinload(MedicalVisit.organ_system_reviews),
                     selectinload(MedicalVisit.physical_exams)
@@ -478,4 +478,32 @@ class MedicalVisitRepository:
                 rest_date_end_spanish=row[27],
                 doctor_name=row[28],
                 doctor_ruc=row[29]
-            )
\ No newline at end of file
+            )
+    
+    def get_medical_diagnoses_command(self, medical_visit_id: str) -> MedicalDiagnosesDTO:
+    
+        with get_session(self.tenant) as session:
+            
+            query = text("""
+                select md."name" as name_diagnosis,
+                md.cie_10_code 
+                from medical_diagnosis md 
+                join medical_diagnosis_visit mdv on mdv.medical_diagnosis_id  = md.medical_diagnosis_id 
+                where md.is_active = true
+                and mdv.is_active  = true
+                and mdv.medical_visit_id  = :medical_visit_id
+            """)
+            
+            result = session.exec(query, params={"medical_visit_id": medical_visit_id})
+            rows = result.fetchall()
+            
+            # Convertir cada fila a DiagnosisDTO
+            diagnoses_list = []
+            for row in rows:
+                diagnosis = DiagnosisDTO(
+                    name_diagnosis=row[0],
+                    cie_10_code=row[1]
+                )
+                diagnoses_list.append(diagnosis)
+            
+            return MedicalDiagnosesDTO(diagnoses=diagnoses_list)
\ No newline at end of file
